@@ -7,9 +7,10 @@
   /* NQS license information */
 #include <nqs_generic/debug.h>
   /* debugging support */
+#include <nqs_generic/proto.h>
+  /* ANSI C prototypes */
 #include <string.h>
 #include <stdlib.h>
-#include <assert.h>
 
 /*** bytezero
  *
