@@ -18,6 +18,8 @@
   /* for definition of time_t */
 #include <nqs_queue/quolim.h>
   /* for definition of struct cpulimit */
+#include <nqs_generic/tblmsgs.h>
+  /* for definition of msgs_table */
 
 /*
  * NOTE - a non-ANSI C compiler will choke on this file.
@@ -52,6 +54,7 @@ extern char *	getenviron	(char *);
 extern char *	getfilnam	(char *, short);
 extern char *	getgrpnam	(gid_t);
 extern char *	getwdir		(void);
+extern short	get_timezone	(struct tm **);
 
 extern int	isdecstr	(char *, int);
 
@@ -71,8 +74,16 @@ extern void	rcimsgs		(long, FILE *, char *, void (*)(FILE *, char *));
 extern void	relfilnam	(char *);
 
 extern int	scancpulim	(char *, struct cpulimit *, short);
-extern int	scanquolim	(char *, struct quotalimit *, short maxonly);
+extern int	scanquolim	(char *, struct quotalimit *, short);
+extern int	scantime	(char *, time_t *, int);
+extern int	scnctime	(char *, time_t *);
+extern int	scnftime	(char *, time_t *);
+extern int	scnptime	(char *, time_t *);
 extern int	secgrfir	(unsigned long, short, unsigned long, short);
 extern void	serexit		(long, char [256]);
 
+extern void	tblmsgs		(long, FILE *, char *, void (*)(FILE *, char *), msg_table *);
+extern void	tcimsgs		(long, FILE *, char *, void (*)(FILE *, char *));
+extern void	tcmmsgs		(long, FILE *, char *prefix);
+
 #endif /* __NQS_GENERIC_PROTO_HEADER */
