@@ -10,7 +10,7 @@ char cTable[] =
   '!', '!' , '!' , '!', '!' , '!', '!' , '!', '!', '!', '!', '!', '!', '!', '!' , '!', /*  48 - 63 */
   '!', '!' , '!' , '!', '!' , '!', '!' , '!', '!', '!', '!', '!', '!', '!', '!' , '!', /*  64 - 79 */
   '!', '!' , '!' , '!', '!' , '!', '!' , '!', '!', '!', '!', '!', '!', '!', '!' , '!', /*  80 - 95 */
-  '!', '\a', '\b', '!', '!' , '!', '\f', '!', '!', '!', '!', '!', '!', '!', '\n', '!', /*  96 - 111 */
+  '!', '!' , '\b', '!', '!' , '!', '\f', '!', '!', '!', '!', '!', '!', '!', '\n', '!', /*  96 - 111 */
   '!', '!' , '\r', '!', '\t', '!', '\v', '!', '!', '!', '!', '!', '!', '!', '!' , '!', /* 112 - 127 */
   '!', '!' , '!' , '!', '!' , '!', '!' , '!', '!', '!', '!', '!', '!', '!', '!' , '!', /* we do not care */
   '!', '!' , '!' , '!', '!' , '!', '!' , '!', '!', '!', '!', '!', '!', '!', '!' , '!', /* once we reach here */
@@ -22,6 +22,13 @@ char cTable[] =
   '!', '!' , '!' , '!', '!' , '!', '!' , '!', '!', '!', '!', '!', '!', '!', '!' , '!'
 };
 
+/*
+ * prototypes
+ */
+
+char * do_convert(char *);
+void   do_printf(char *, ...);
+
 char * do_convert(char *szIn)
 {
   char *szFormat;
